pub struct NodeInstance {
pub node: NodeNode,
pub static_args: StaticArgs,
}Expand description
A node and a set of static arguments for it
Non-parametric nodes always have one and only one instance. Parametric notes may have as many instances as the number of possible values that a tuple matching its static parameters types could hold. In reality, only instances that are directly or indirectly referred to in the code will be created.
See also
all_instancesto obtain a compilation unit-wide list of node instances
Fields
node: NodeNodestatic_args: StaticArgsImplementations
Sourceimpl NodeInstance
impl NodeInstance
pub fn new_non_parametric(node: NodeNode) -> Self
pub fn new_parametric(node: NodeNode, static_args: StaticArgs) -> Self
pub fn is_parametric(&self) -> bool