pub struct StaticArgs { /* private fields */ }Expand description
Set of static arguments that can be compared for semantic equality
Two call sites whose static argument set resolves to the same values will have the same
StaticArgs value, and subsequently the same NodeInstance value, provided that they call
the same node.
Implementations
Sourceimpl StaticArgs
impl StaticArgs
pub fn values(&self) -> impl Iterator<Item = &StaticArg>
pub fn get(&self, id: &Id) -> Option<&StaticArg>
pub fn resolve_type(&self, id: &Id) -> Option<&Type>
pub fn resolve_const(&self, id: &Id) -> Option<&Value>
pub fn resolve_node(&self, id: &Id) -> Option<&NodeInstance>